/*
 * UPIWIN - Micro Pi Windowing Framework Kernel
 * Copyright (C) 2019 Amy Bowersox/Erbosoft Metaverse Design Solutions
 *    
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *    
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *-------------------------------------------------------------------------
 */
#ifndef __EP_UTIL_H_INCLUDED
#define __EP_UTIL_H_INCLUDED

#define PY_SSIZE_T_CLEAN
#include <Python.h>
#include "wintype.h"

typedef struct tagREGCONSTANT {
	CHAR regtype;
	PCSTR name;
	union {
		LONG ival;
		PCSTR sval;
	} value;
} REGCONSTANT, *PREGCONSTANT;

typedef const REGCONSTANT *PCREGCONSTANT;

extern void Epython_log_object(int level, const char *label, PyObject *object);
extern HRESULT Epython_trace_exception(void);
extern HRESULT Epython_register_constants(PyObject *module, PCREGCONSTANT const_table);

#define BEGIN_CONSTANT_TABLE(name)    static const REGCONSTANT name[] = {
#define CONSTANT_INT(name, value)     { 'i', name, { .ival = value } },
#define CONSTANT_INT_MACRO(mac)       CONSTANT_INT(#mac, mac)
#define CONSTANT_STRING(name, value)  { 's', name, { .sval = value } },
#define CONSTANT_STRING_MACRO(mac)    CONSTANT_STRING(#mac, mac)
#define END_CONSTANT_TABLE            { 0, NULL, { .sval = NULL } } };

#endif /* __EP_UTIL_H_INCLUDED */
