/*
 * UPIWIN - Micro Pi Windowing Framework Kernel
 * Copyright (C) 2019 Amy Bowersox/Erbosoft Metaverse Design Solutions
 *    
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *    
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *-------------------------------------------------------------------------
 */
#ifndef __FBINIT_H_INCLUDED
#define __FBINIT_H_INCLUDED

#include "wintype.h"

/* info about the frame buffer */
typedef struct tagFBINFO {
  UINT32 width;               /* screen width */
  UINT32 height;              /* screen height */
  UINT32 virtual_width;       /* virtual screen width */
  UINT32 virtual_height;      /* virtual screen height */
  UINT32 bpp;                 /* bits per pixel (16) */
  UINT32 linebytes;           /* number of bytes per line */
  UINT32 screenbytes;         /* number of bytes for the entire screen */
  UINT16 red_offset;          /* offset of "red" bits within pixel word (11) */
  UINT16 red_length;          /* number of "red" bits within pixel word (5) */
  UINT16 red_mask;            /* mask for the "red" bits in a pixel word */
  UINT16 green_offset;        /* offset of "green" bits within pixel word (5) */
  UINT16 green_length;        /* number of "green" bits within pixel word (6) */
  UINT16 green_mask;          /* mask for the "green" bits in a pixel word */
  UINT16 blue_offset;         /* offset of "blue" bits within pixel word (0) */
  UINT16 blue_length;         /* number of "blue" bits within pixel word (5) */
  UINT16 blue_mask;           /* mask for the "blue" bits in a pixel word */
} FBINFO;
typedef const FBINFO * const PCFBINFO;

extern PCFBINFO Fb_Info;     /* pointer to screen information */
extern UINT16 *Fb_Ptr;       /* pointer to memory-mapped screen buffer */

extern HRESULT Fb_setup(void);
extern void Fb_clear(void);

#endif /* __FBINIT_H_INCLUDED */
